@@ -14,6 +14,8 @@ INVERTER_ID = 10
 
 @dataclass
 class SolarData:
+    """Solar data returned from the inverter API."""
+
     daily_energy: float  # kiloWatthour
     current_power: int  # Watt
 
@@ -36,8 +38,7 @@ def _parse_content(incoming: bytes) -> SolarData:
         _daily_energy = float(data[DAILY_ENERGY_IDX])
         _current_power = int(data[CURRENT_POWER_INDEX])
     except (ValueError, IndexError) as err:
-        _LOGGER.error("Unable to parse incoming data %s", incoming)
-        raise ZeverError(err) from None
+        raise ZeverError(err) from err
     else:
         return SolarData(_daily_energy, _current_power)
 
@@ -45,9 +46,8 @@ def _parse_content(incoming: bytes) -> SolarData:
 def _parse_zever_id(incoming: bytes) -> str:
     data = incoming.split()
     try:
-        return _convert_to_string(data[10])
+        return _convert_to_string(data[INVERTER_ID])
     except (ValueError, IndexError) as err:
-        _LOGGER.error("Unable to parse incoming data %s", incoming)
         raise ZeverError(err) from None
 
 
@@ -55,7 +55,7 @@ class ClientAdapter(ABC):
     """http client base adapter."""
 
     @abstractmethod
-    async def get(self, url, timeout=2) -> bytes:
+    async def get(self, url: str, timeout: int = 2) -> bytes:
         """Return the url response data."""
         ...
 
@@ -63,7 +63,8 @@ class ClientAdapter(ABC):
 class HttpxClient(ClientAdapter):
     """Httpx client adapter"""
 
-    async def get(self, url, timeout=2) -> bytes:
+    async def get(self, url: str, timeout: int = 2) -> bytes:
+        """Return a client request."""
         try:
             async with httpx.AsyncClient() as client:
                 data = await client.get(url, timeout=timeout)
@@ -74,7 +75,7 @@ class HttpxClient(ClientAdapter):
         return data.content
 
 
-def default_url(ip_address: str):
+def default_url(ip_address: str) -> str:
     """Return the default url based on the provided ip address
     Address only ie. 192.168.1.3"""
 
@@ -82,38 +83,54 @@ def default_url(ip_address: str):
 
 
 def client_factory(client: Optional[ClientAdapter]) -> ClientAdapter:
+    """Return a ClientAdapter instance."""
     if client is None:
         return HttpxClient()
-    else:
-        return client
+    return client
 
 
-async def solardata(url: str, client: ClientAdapter = None) -> SolarData:
+async def solardata(
+    url: str, client: Optional[ClientAdapter] = None, timeout: int = 2
+) -> SolarData:
     """Query the local zever solar inverter for new data.
-
+    Returns:
+        SolarData. Dataclass containing solar data.
     Raises:
         ZeverError when data is incorrect.
         ZeverTimeout when connecting to the inverter times out.
-            For example when the invertor is off as there is no sun to
-            power the invertor.
+            For example when the inverter is off as there is no sun to
+            power the inverter.
     """
     client = client_factory(client)
 
-    data = await client.get(url)
+    data = await client.get(url, timeout=timeout)
 
     return _parse_content(data)
 
 
-async def inverter_id(url: str, client: ClientAdapter = None) -> str:
+async def inverter_id(
+    url: str, client: Optional[ClientAdapter] = None, timeout: int = 2
+) -> str:
+    """Query the local zever solar inverter for the id of the inverter.
+
+    Returns:
+        String of the zever inverter id.
+
+    Raises:
+        ZeverError when data is incorrect.
+        ZeverTimeout when connecting to the inverter times out.
+            For example when the inverter is off as there is no sun to
+            power the inverter.
+    """
     client = client_factory(client)
 
-    data = await client.get(url)
+    data = await client.get(url, timeout=timeout)
 
     return _parse_zever_id(data)
 
 
 class ZeverError(Exception):
-    """Parsing problem"""
+    """General Zever problem"""
 
 
 class ZeverTimeout(ZeverError):
